# plots for the stecf comments section

library(ggplot2)
load("RData.nea")
load("RData.med")
theme_set(theme_bw())
options(stringsAsFactors=FALSE)
vp <- dy
vp[c(2,4,6,8,10,12,14)] <- ""
v0 <- vp
sc <- scale_x_continuous(breaks=dy, labels=as.character(v0))
th <- theme(axis.text  = element_text(angle=0, vjust=0.5, size=8), panel.grid.minor = element_blank(), legend.title  = element_text(size=8), legend.text  = element_text(size=8), axis.title.y  = element_text(size=8), legend.background = element_rect(fill="transparent"))

# fig221

df0 <- fInda
df0$stat <- fInda$N/(fInda$N+fIndb$N)
df0$Indicator <- "Overfished stocks (n = 70 stocks)"

df1 <- fInda
df1$stat <- fIndc$N/(fIndc$N+fIndd$N)
df1$Indicator <- "Outside Safe Bio Limits (n = 46 stocks)"

#df2 <- fInda
#df2$stat <- fIndf$N/(fIndf$N+fIndfb$N) 
#df2$Indicator <- "F > Fmsy or SSB < MSYBtrigger"

df0 <- rbind(df0, df1)
df0 <- subset(df0, EcoRegion=='ALL')

png("fig221.png", 1800, 1000, res=300)
ggplot(df0, aes(x=Year, y=stat*100, colour=Indicator, shape=Indicator)) + 
	geom_line(size=1) + 
	geom_point(size=2) +
	ylab("Percentage of stocks") + 
	xlab("") + 
	ylim(c(0,100)) + 
	sc + 
	th + 
	theme(legend.position=c(0.25, 0.25)) +
	scale_color_manual(values=c("orange", "blue"))
dev.off()	

# fig 222
df0 <- do.call("rbind", ifit.bs)
df0 <- data.frame(Year=dy, stat=apply(df0, 2, quantile, 0.50, na.rm=TRUE), Indicator="NEA: EU waters (n = 48 stocks)")

df1 <- do.call("rbind", ifitout.bs)
df1 <- data.frame(Year=dy, stat=apply(df1, 2, quantile, 0.50, na.rm=TRUE), Indicator="NEA: outside EU waters (n = 11 stocks)")

df2 <- do.call("rbind", mfit.bs)
df2 <- data.frame(Year=dy[-length(dy)], stat=apply(df2, 2, quantile, 0.50, na.rm=TRUE), Indicator="MED&BS: EU waters (n = 47 stocks)")

df0 <- rbind(df0, df1, df2)

png("fig222.png", 1800, 1000, res=300)
ggplot(df0, aes(x=Year, y=stat, colour=Indicator, shape=Indicator)) + 
	geom_hline(yintercept = 1, linetype=2, size=0.5) +
	geom_line(size=1) + 
	geom_point(size=2) +
	xlab("") + 
	ylab(expression(F/F[MSY])) + 
	ylim(c(0,3)) + 
	sc + 
	th + 
	theme(legend.position=c(0.25, 0.25)) + 
	scale_color_manual(values=c("black", "red", "green"))
dev.off()	

# fig 223
ifitm <- do.call("rbind", ifitb.bs)
df0 <- exp(log(ifitm)-mean(log(ifitm[,1]), na.rm=TRUE))
df0 <- data.frame(Year=dy, stat=apply(df0, 2, quantile, 0.50, na.rm=TRUE), Indicator="Biomass in NEA (n = 55 stocks)")

mfitm <- do.call("rbind", mfitb.bs)
df1 <- exp(log(mfitm)-mean(log(mfitm[,1]), na.rm=TRUE))
df1 <- data.frame(Year=dy[-length(dy)], stat=apply(df1, 2, quantile, 0.50, na.rm=TRUE), Indicator="Biomass in MED&BS (n = 45 stocks)")

ifitm <- do.call("rbind", ifitb3.bs)
df2 <- exp(log(ifitm)-mean(log(ifitm[,1]), na.rm=TRUE))
df2 <- data.frame(Year=dy, stat=apply(df2, 2, quantile, 0.50, na.rm=TRUE), Indicator="Biomass in NEA for data poor stocks (ICES category 3) (n = 72 stocks)")

df0 <- rbind(df0, df1, df2)

png("fig223.png", 1800, 1000, res=300)
ggplot(df0, aes(x=Year, y=stat, colour=Indicator, shape=Indicator)) + 
	geom_hline(yintercept = 1, linetype=2, size=0.5) +
	geom_line(size=1) + 
	geom_point(size=2) +
	xlab("") + 
	ylab(expression(B/B[2003])) + 
	ylim(c(0,2)) + 
	sc + 
	th + 
	theme(legend.position=c(0.4, 0.25)) + 
	scale_color_manual(values=c("black", "blue", "green"))
dev.off()	

# fig 224
ifitm <- do.call("rbind", ifitr.bs)
df0 <- exp(log(ifitm)-mean(log(ifitm[,1]), na.rm=TRUE))
df0 <- data.frame(Year=dy, stat=apply(df0, 2, quantile, 0.50, na.rm=TRUE), Indicator="Decadal recruitment in NEA (n = 55 stocks)")

png("fig224.png", 1800, 1000, res=300)
ggplot(df0, aes(x=Year, y=stat, colour=Indicator, shape=Indicator)) + 
	geom_hline(yintercept = 1, linetype=2, size=0.5) +
	geom_line(size=1) + 
	geom_point(size=2) +
	xlab("") + 
	ylab("Decadal recruitment") + 
	ylim(c(0,2)) + 
	sc + 
	th + 
	theme(legend.position=c(0.25, 0.25)) + 
	scale_color_manual(values=c("black"))
dev.off()	

